#define F_CPU 16000000
#include <avr/io.h>
#include <util/delay.h>
#include <avr/interrupt.h>

#define LED_ON PORTD |= (1 << PD7)
#define LED_OFF PORTD &= ~(1 << PD7)
#define LED_TOGGLE PORTD ^= (1 << PD7)

void init_PORTS() {
    DDRD |= (1 << PD7); // OUTPUT LED
    DDRB |= (1 << PD0 | 1 << PD1 | 1 << PD2 | 1 << PD3); // IN1, IN2, IN3, IN4
    
    DDRA &= ~((1 << PA0) | (1 << PA1) | (1 << PA2)); 
    PORTA |= (1 << PA0) | (1 << PA1) | (1 << PA2); // INPUTS R, C, L
}

void MOTORL_FORWARD() {
    PORTD |= 1 << PD1;
    PORTD &= ~(1 << PD0);
    PORTB |= 1 << PB3;
}

void MOTORL_STOP() {
    PORTD &= ~(1 << PD1);
    PORTB &= ~(1 << PB3);
}

void MOTORR_FORWARD() {
    PORTD |= (1 << PD2 | 1 << PD7);
    PORTD &= ~(1 << PD3);
}

void MOTORR_STOP() {
    PORTD &= ~(1 << PD2);
    PORTD &= ~(1 << PD7);
}

#define CENTER PINA & (1 << PA1) 
#define RIGHT PINA & (1 << PA0)
#define LEFT PINA & (1 << PA2)

int main() {
    init_PORTS();
    int R = 0, C = 0, L = 0;
    while(1) {
        if (!(CENTER)) { 
            //OCR0A = 255;
            //OCR0B = 255;
            MOTORL_FORWARD();
            MOTORR_FORWARD();
        } else if (!(RIGHT)) {
            //OCR0A = 128;
            MOTORL_FORWARD();
            MOTORR_STOP();   
            
        } else if (!(LEFT)) {
            //OCR2A = 128;
            MOTORR_FORWARD();
            MOTORL_STOP();  
        } else {
	    if (!L && R) {    
            	MOTORR_FORWARD();
            	MOTORL_STOP();
	    }

	    if (L && !R) {
 	    	MOTORL_FORWARD();
            	MOTORR_STOP();
	    }
        }
	
        C = CENTER;
        R = RIGHT;
        L = LEFT;
    }

    return 0;
}
